.. _probe_class:

The Probe class
---------------
Those can contain all their elements or be sparse


Convention on positive elements etc
-----------------------------------
Blab


Possible to create multiple ways
--------------------------------
Two ways to build them
Call them by their name
Give all the required parameters and build one (minimum → geometry_type,
nb_elements, central_freq, pitch)
